Twistless
=========

A simple to use bridge between stackless python (available in pypy) and the
twisted networking library.

For detailed documentation go to https://impyccable.readthedocs.org/ for the
most up to date info.
